pub enum ReviewReason {
EnrollmentNotReady,
CapacityUnknown,
}Expand description
Reason staff must review a training assignment before it can be drafted.
Variants
EnrollmentNotReady
Staff can see the enrollment not ready training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
CapacityUnknown
Staff can see the capacity unknown training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.