pub enum WaitlistReason {
RequestedTrainerUnavailable,
CapacitySnapshotUnavailable,
}Expand description
Reason staff should waitlist a training assignment instead of drafting it.
Variants
Staff can see the requested trainer unavailable training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Staff can see the capacity snapshot unavailable training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.